[evolution/account-mgmt: 15/50] Adapt addressbook/tools to the new ESource API.



commit b54be8fd7cbd893955d4229e985c388464d042e0
Author: Matthew Barnes <mbarnes redhat com>
Date:   Wed Dec 8 00:17:41 2010 -0500

    Adapt addressbook/tools to the new ESource API.

 .../evolution-addressbook-export-list-cards.c      |   53 ++++++---
 .../evolution-addressbook-export-list-folders.c    |  124 +++++++++++---------
 addressbook/tools/evolution-addressbook-export.c   |   15 ++-
 addressbook/tools/evolution-addressbook-export.h   |    2 +-
 4 files changed, 114 insertions(+), 80 deletions(-)
---
diff --git a/addressbook/tools/evolution-addressbook-export-list-cards.c b/addressbook/tools/evolution-addressbook-export-list-cards.c
index 41d2217..c38afff 100644
--- a/addressbook/tools/evolution-addressbook-export-list-cards.c
+++ b/addressbook/tools/evolution-addressbook-export-list-cards.c
@@ -24,6 +24,7 @@
 #include <config.h>
 #endif
 
+#include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -34,6 +35,8 @@
 #include <libebook/e-book-client.h>
 #include <libebook/e-book-query.h>
 #include <libebook/e-contact.h>
+#include <libebook/e-source-address-book.h>
+#include <libedataserver/e-source-registry.h>
 
 #include "evolution-addressbook-export.h"
 
@@ -639,8 +642,8 @@ action_list_cards (GSList *contacts,
 	length = g_slist_length (contacts);
 
 	if (length <= 0) {
-		g_warning ("Couldn't load addressbook correctly!!!! %s####", p_actctx->action_list_cards.addressbook_folder_uri ?
-				p_actctx->action_list_cards.addressbook_folder_uri : "NULL");
+		g_warning ("Couldn't load addressbook correctly!!!! %s####", p_actctx->action_list_cards.addressbook_source_uid ?
+				p_actctx->action_list_cards.addressbook_source_uid : "NULL");
 		exit (-1);
 	}
 
@@ -771,30 +774,48 @@ set_pre_defined_field (GSList **pre_defined_fields)
 guint
 action_list_cards_init (ActionContext *p_actctx)
 {
+	ESourceRegistry *registry;
 	EBookClient *book_client;
 	EBookQuery *query;
-	gchar *query_str;
+	ESource *source;
 	GSList *contacts;
+	const gchar *uid;
+	gchar *query_str;
 	GError *error = NULL;
 
-	if (p_actctx->action_list_cards.addressbook_folder_uri != NULL) {
-		book_client = e_book_client_new_from_uri (p_actctx->action_list_cards.addressbook_folder_uri, &error);
-	} else {
-		book_client = e_book_client_new_default (&error);
-	}
+	/* Register the "Address Book" extension. */
+	E_TYPE_SOURCE_ADDRESS_BOOK;
+
+	registry = e_source_registry_get_default ();
+
+	e_source_registry_load_sources (registry, NULL);
+
+	uid = p_actctx->action_list_cards.addressbook_source_uid;
 
-	if (!book_client
-	    || !e_client_open_sync (E_CLIENT (book_client), TRUE, NULL, &error)) {
-		g_warning ("Couldn't load addressbook %s: %s", p_actctx->action_list_cards.addressbook_folder_uri ?
-				p_actctx->action_list_cards.addressbook_folder_uri : "'default'",
-				error ? error->message : "Unknown error");
-		if (error)
-			g_error_free (error);
-		if (book_client)
+	if (uid != NULL)
+		source = e_source_registry_lookup_by_uid (registry, uid);
+	else
+		source = e_source_registry_get_default_address_book (registry);
+
+	book_client = e_book_client_new (source, &error);
+
+	if (book_client != NULL)
+		e_client_open_sync (E_CLIENT (book_client), TRUE, NULL, &error);
+
+	if (error != NULL) {
+		g_warning (
+			"Couldn't load addressbook %s: %s",
+			p_actctx->action_list_cards.addressbook_source_uid ?
+			p_actctx->action_list_cards.addressbook_source_uid :
+			"'default'", error->message);
+		if (book_client != NULL)
 			g_object_unref (book_client);
+		g_error_free (error);
 		exit (-1);
 	}
 
+	g_return_val_if_fail (E_IS_BOOK_CLIENT (book_client), FAILED);
+
 	query = e_book_query_any_field_contains ("");
 	query_str = e_book_query_to_string (query);
 	e_book_query_unref (query);
diff --git a/addressbook/tools/evolution-addressbook-export-list-folders.c b/addressbook/tools/evolution-addressbook-export-list-folders.c
index 2628c9c..081367a 100644
--- a/addressbook/tools/evolution-addressbook-export-list-folders.c
+++ b/addressbook/tools/evolution-addressbook-export-list-folders.c
@@ -22,31 +22,32 @@
  */
 
 #include <config.h>
+#include <stdlib.h>
 
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 
 #include <libebook/e-book-client.h>
 #include <libebook/e-book-query.h>
+#include <libebook/e-source-address-book.h>
+#include <libedataserver/e-source-registry.h>
 
 #include "evolution-addressbook-export.h"
 
 guint
 action_list_folders_init (ActionContext *p_actctx)
 {
-	ESourceList *addressbooks = NULL;
-	GSList *groups, *group;
+	ESourceRegistry *registry;
+	GList *list, *iter;
 	FILE *outputfile = NULL;
-	GError *error = NULL;
-	EBookQuery *query;
-	gchar *query_str;
+	const gchar *extension_name;
 
-	if (!e_book_client_get_sources (&addressbooks, &error)) {
-		g_warning (_("Couldn't get list of address books: %s"), error ? error->message : _("Unknown error"));
-		if (error)
-			g_error_free (error);
-		exit (-1);
-	}
+	/* Register the "Address Book" extension. */
+	E_TYPE_SOURCE_ADDRESS_BOOK;
+
+	registry = e_source_registry_get_default ();
+
+	e_source_registry_load_sources (registry, NULL);
 
 	if (p_actctx->action_list_folders.output_file != NULL) {
 		if (!(outputfile = g_fopen (p_actctx->action_list_folders.output_file, "w"))) {
@@ -55,55 +56,64 @@ action_list_folders_init (ActionContext *p_actctx)
 		}
 	}
 
-	query = e_book_query_any_field_contains ("");
-	query_str = e_book_query_to_string (query);
-	e_book_query_unref (query);
-
-	groups = e_source_list_peek_groups (addressbooks);
-	for (group = groups; group; group = group->next) {
-		ESourceGroup *g = group->data;
-		GSList *sources, *source;
-
-		sources = e_source_group_peek_sources (g);
-		for (source = sources; source; source = source->next) {
-			ESource *s = source->data;
-			EBookClient *book_client;
-			GSList *contacts;
-			gchar *uri;
-			const gchar *name;
-
-			error = NULL;
-			book_client = e_book_client_new (s, &error);
-			if (!book_client
-			    || !e_client_open_sync (E_CLIENT (book_client), TRUE, NULL, &error)) {
-				g_warning (_("Failed to open client '%s': %s"), e_source_peek_name (s), error ? error->message : _("Unknown error"));
-				if (error)
-					g_error_free (error);
-				continue;
-			}
-
-			if (!e_book_client_get_contacts_sync (book_client, query_str, &contacts, NULL, &error))
-				contacts = NULL;
-
-			uri = e_source_get_uri (s);
-			name = e_source_peek_name (s);
-
-			if (outputfile)
-				fprintf (
-					outputfile, "\"%s\",\"%s\",%d\n",
-					uri, name, g_slist_length (contacts));
-			else
-				printf ("\"%s\",\"%s\",%d\n", uri, name, g_slist_length (contacts));
-
-			g_free (uri);
-			g_slist_foreach (contacts, (GFunc) g_object_unref, NULL);
-			g_slist_free (contacts);
-
-			g_object_unref (book_client);
+	extension_name = E_SOURCE_EXTENSION_ADDRESS_BOOK;
+	list = e_source_registry_list_sources (registry, extension_name);
+
+	for (iter = list; iter != NULL; iter = g_list_next (iter)) {
+		EBookClient *book_client;
+		EBookQuery *query;
+		ESource *source;
+		GSList *contacts;
+		const gchar *display_name;
+		const gchar *uid;
+		gchar *query_str;
+		GError *error = NULL;
+
+		source = E_SOURCE (iter->data);
+
+		book_client = e_book_client_new (source, &error);
+
+		if (book_client != NULL)
+			e_client_open_sync (
+				E_CLIENT (book_client), TRUE, NULL, &error);
+
+		if (error != NULL) {
+			g_warning (
+				_("Failed to open client '%s': %s"),
+				e_source_get_display_name (source),
+				error->message);
+			if (book_client != NULL)
+				g_object_unref (book_client);
+			g_error_free (error);
+			continue;
 		}
+
+		query = e_book_query_any_field_contains ("");
+		query_str = e_book_query_to_string (query);
+		e_book_query_unref (query);
+
+		e_book_client_get_contacts_sync (
+			book_client, query_str, &contacts, NULL, NULL);
+
+		display_name = e_source_get_display_name (source);
+		uid = e_source_get_uid (source);
+
+		if (outputfile)
+			fprintf (
+				outputfile, "\"%s\",\"%s\",%d\n",
+				uid, display_name, g_slist_length (contacts));
+		else
+			printf (
+				"\"%s\",\"%s\",%d\n",
+				uid, display_name, g_slist_length (contacts));
+
+		g_slist_foreach (contacts, (GFunc) g_object_unref, NULL);
+		g_slist_free (contacts);
+
+		g_object_unref (book_client);
 	}
 
-	g_free (query_str);
+	g_list_free (list);
 
 	if (outputfile)
 		fclose (outputfile);
diff --git a/addressbook/tools/evolution-addressbook-export.h b/addressbook/tools/evolution-addressbook-export.h
index 804bd50..3739dd6 100644
--- a/addressbook/tools/evolution-addressbook-export.h
+++ b/addressbook/tools/evolution-addressbook-export.h
@@ -55,7 +55,7 @@ union _ActionContext
 		gchar *output_file;
 		gint IsCSV;
 		gint IsVCard;
-		gchar *addressbook_folder_uri;
+		gchar *addressbook_source_uid;
 		gint async_mode;
 		gint file_size;
 	}



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/addressbook/tools/evolution-addressbook-export.c b/addressbook/tools/evolution-addressbook-export.c
index 5460c5a..57889a3 100644
--- a/addressbook/tools/evolution-addressbook-export.c
+++ b/addressbook/tools/evolution-addressbook-export.c
@@ -24,6 +24,7 @@
 #include <config.h>
 #endif
 
+#include <stdlib.h>
 #include <string.h>
 #include <glib/gi18n.h>
 
@@ -49,7 +50,7 @@
 static gchar *opt_output_file = NULL;
 static gboolean opt_list_folders_mode = FALSE;
 static gchar *opt_output_format = NULL;
-static gchar *opt_addressbook_folder_uri = NULL;
+static gchar *opt_addressbook_source_uid = NULL;
 static gboolean opt_async_mode = FALSE;
 static gint opt_file_size = 0;
 static gchar **opt_remaining = NULL;
@@ -130,12 +131,13 @@ main (gint argc,
 
 	/* Parsing Parameter */
 	if (opt_remaining && g_strv_length (opt_remaining) > 0)
-		opt_addressbook_folder_uri = g_strdup (opt_remaining[0]);
+		opt_addressbook_source_uid = g_strdup (opt_remaining[0]);
 
 	if (opt_list_folders_mode != FALSE) {
 		current_action = ACTION_LIST_FOLDERS;
-		/* check there should not be addressbook-folder-uri , and async and size , output_format */
-		if (opt_addressbook_folder_uri != NULL || opt_async_mode != FALSE || opt_output_format != NULL || opt_file_size != 0) {
+		/* check there should not be addressbook-source-uid,
+		 * and async and size, output_format */
+		if (opt_addressbook_source_uid != NULL || opt_async_mode != FALSE || opt_output_format != NULL || opt_file_size != 0) {
 			g_warning (_("Command line arguments error, please use --help option to see the usage."));
 			exit (-1);
 		}
@@ -191,7 +193,8 @@ main (gint argc,
 		}
 		actctx.action_list_cards.IsCSV = IsCSV;
 		actctx.action_list_cards.IsVCard = IsVCard;
-		actctx.action_list_cards.addressbook_folder_uri = g_strdup (opt_addressbook_folder_uri);
+		actctx.action_list_cards.addressbook_source_uid =
+			g_strdup (opt_addressbook_source_uid);
 		actctx.action_list_cards.async_mode = opt_async_mode;
 		actctx.action_list_cards.file_size = opt_file_size;
 
@@ -204,5 +207,5 @@ main (gint argc,
 
 	/*FIXME:should free actctx's some gchar * field, such as output_file! but since the program will end, so that will not cause mem leak.  */
 
-	exit (0);
+	return 0;
 }